@@ -241,7 +241,7 @@ pub fn create_cmd(
         command.arg("-NonInteractive");
         command.arg("-NoLogo");
         // ensure file operations use UTF8
-        let mut run_str = String::from("$PSDefaultParameterValues['Out-File:Encoding']='utf8';");
+        let mut run_str = String::from("$PSDefaultParameterValues['Out-File:Encoding']='utf8';$ErrorActionPreference='Stop';");
         // we also set _custom_ variables as local variables for easy substitution
         for (name, value) in &batch_cmd.env {
             run_str.push_str(&format!("${}='{}';", name, value.replace("'", "''")));
@@ -364,6 +364,7 @@ pub fn create_cmd(
         command.env(name, value);
     }
     command.current_dir(cwd);
+    command.arg("-e");
     command.arg("-c");
     command.arg(&run);
     set_cmd_stdio(&mut command, batch_cmd.stdio.unwrap_or_default());
